@@ -6,7 +6,7 @@
 package POE::Loop::IO_Poll;
 
 use vars qw($VERSION);
-$VERSION = '1.353'; # NOTE - Should be #.### (three decimal places)
+$VERSION = '1.355'; # NOTE - Should be #.### (three decimal places)
 
 # Include common signal handling.
 use POE::Loop::PerlSignals;
@@ -67,7 +67,7 @@ BEGIN {
 my %poll_fd_masks;
 
 # Allow $^T to change without affecting our internals.
-my $start_time = $^T;
+my $start_time = monotime();
 
 #------------------------------------------------------------------------------
 # Loop construction and destruction.
@@ -95,7 +95,7 @@ sub loop_attach_uidestroy {
 # value.  A "paused" time watcher is just a timeout for some future
 # time.
 
-my $_next_event_time = time();
+my $_next_event_time = monotime();
 
 sub loop_resume_time_watcher {
   $_next_event_time = $_[1];
@@ -106,7 +106,7 @@ sub loop_reset_time_watcher {
 }
 
 sub loop_pause_time_watcher {
-  $_next_event_time = time() + 3600;
+  $_next_event_time = monotime() + 3600;
 }
 
 # A static function; not some object method.
@@ -232,7 +232,7 @@ sub loop_do_timeslice {
 
   my $timeout = $_next_event_time;
 
-  my $now = time();
+  my $now = monotime();
   if (defined $timeout) {
     $timeout -= $now;
     $timeout = 0 if $timeout < 0;
